@@ -11,7 +11,7 @@ use Storable qw(dclone);
 use Test::Builder;
 use Test::Class::MethodInfo;
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 my $Check_block_has_run;
 {
@@ -154,7 +154,8 @@ sub _get_methods {
 		};
 	};
 
-    return sort keys %methods;
+    my @methods = sort keys %methods;
+    return @methods;
 };
 
 sub _num_expected_tests {
@@ -265,7 +266,8 @@ sub _run_method {
 		_exception_failure($self, $method, $exception, $tests) 
 				unless $exception eq '';
 	} elsif ($num_done > $num_expected) {
-		$Builder->diag("expected $num_expected test(s) in $method, $num_done completed\n");
+        my $class = ref $self;
+		$Builder->diag("expected $num_expected test(s) in $class\::$method, $num_done completed\n");
 	} else {
 		until (($Builder->current_test - $num_start) >= $num_expected) {
 			if ($exception ne '') {
@@ -1599,11 +1601,11 @@ various anonymous folk and all the fine people on perl-qa for their feedback, pa
 This module wouldn't be possible without the excellent L<Test::Builder>. Thanks to chromatic and Michael G Schwern for creating such a useful module.
 
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Adrian Howard <adrianh@quietstars.com>
+Adrian Howard <adrianh@quietstars.com>, Curtis "Ovid" Poe, <ovid at cpan.org>, Mark Morgan <makk384@gmail.com>.
 
-If you use this module, and can spare the time please drop me an e-mail or rate it at L<http://cpanratings.perl.org/rate/?distribution=Test-Class>.
+If you use this module, and can spare the time please let us know or rate it at L<http://cpanratings.perl.org/rate/?distribution=Test-Class>.
 
 =head1 SEE ALSO
 
